Skip to content
On this page

WARDuino Architecture ​

This page gives an overview of the core components of the WARDuino virtual machine

Classic Remote Debugger ​

WARDuino facilitates remote debugging by allowing debug messages to be sent over a variety of carriers, such as USB (wired) or Wi-Fi (wireless) communication. In theory any communication channel that reliably signals at least one readable pin on the device can be used.